==> paraview_5.9.0.orig.tar.xz: paraview-5.9.0/Qt/Core/pqLinkViewWidget.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqLinkViewWidget.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#ifndef pqLinkViewWidget_h
#define pqLinkViewWidget_h

#include <QWidget>
#include <pqCoreModule.h>

class pqRenderView;
class QCheckBox;
class QLineEdit;

/**
* a popup window that helps the user select another view
* to link with
*/
class PQCORE_EXPORT pqLinkViewWidget : public QWidget
{
  Q_OBJECT
public:
  /**
  * constructor takes the first view
  */
  pqLinkViewWidget(pqRenderView* firstLink);
  /**
  * destructor
  */
  ~pqLinkViewWidget() override;

protected:
  /**
  * event filter to monitor user's selection
  */
  bool eventFilter(QObject* watched, QEvent* e) override;
  /**
  * watch internal events
  */
  bool event(QEvent* e) override;

private:
  pqRenderView* RenderView;
  QLineEdit* LineEdit;
  QCheckBox* InteractiveViewLinkCheckBox;
};

#endif

==> paraview_5.10.0~rc1.orig.tar.xz: paraview-5.10.0~rc1/Qt/Core/pqLinkViewWidget.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqLinkViewWidget.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#ifndef pqLinkViewWidget_h
#define pqLinkViewWidget_h

#include <QWidget>
#include <pqCoreModule.h>

class pqRenderView;
class QCheckBox;
class QLineEdit;

/**
 * a popup window that helps the user select another view to link with
 */
class PQCORE_EXPORT pqLinkViewWidget : public QWidget
{
  Q_OBJECT
public:
  /**
   * constructor takes the first view
   */
  pqLinkViewWidget(pqRenderView* firstLink);
  /**
   * destructor
   */
  ~pqLinkViewWidget() override;

protected:
  /**
   * event filter to monitor user's selection
   */
  bool eventFilter(QObject* watched, QEvent* e) override;
  /**
   * watch internal events
   */
  bool event(QEvent* e) override;

private:
  pqRenderView* RenderView;
  QLineEdit* LineEdit;
  QCheckBox* InteractiveViewLinkCheckBox;
};

#endif
